aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/core
diff options
context:
space:
mode:
authorGravatar Jonathan Hseu <jhseu@google.com>2016-11-18 10:55:00 -0800
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2016-11-18 11:06:39 -0800
commitd0aac2b02faf2552b0663763a0cc552fcce5febe (patch)
tree79969c1e269d6d31c4dbf71e52e76254bf1fcb62 /tensorflow/core
parent1b7bd69f5fcc31c9e3163ff1702a9ea117a64d5a (diff)
Automated rollback of change 139371663
Change: 139598626
Diffstat (limited to 'tensorflow/core')
-rw-r--r--tensorflow/core/ops/array_ops.cc8
-rw-r--r--tensorflow/core/ops/linalg_ops.cc2
-rw-r--r--tensorflow/core/ops/logging_ops.cc6
-rw-r--r--tensorflow/core/ops/math_ops.cc8
-rw-r--r--tensorflow/core/ops/sparse_ops.cc8
-rw-r--r--tensorflow/core/ops/state_ops.cc20
-rw-r--r--tensorflow/core/ops/string_ops.cc4
7 files changed, 28 insertions, 28 deletions
diff --git a/tensorflow/core/ops/array_ops.cc b/tensorflow/core/ops/array_ops.cc
index 25972252c5..72724007d8 100644
--- a/tensorflow/core/ops/array_ops.cc
+++ b/tensorflow/core/ops/array_ops.cc
@@ -305,7 +305,7 @@ concat_dim: 0-D. The dimension along which to concatenate. Must be in the
range [0, rank(values)).
values: The `N` Tensors to concatenate. Their ranks and types must match,
and their sizes must match in all dimensions except `concat_dim`.
-output: An `Output` with the concatenation of values stacked along the
+output: A `Tensor` with the concatenation of values stacked along the
`concat_dim` dimension. This tensor's shape matches that of `values` except
in `concat_dim` where it has the sum of the sizes.
)doc");
@@ -325,7 +325,7 @@ values: List of `N` Tensors to concatenate. Their ranks and types must match,
and their sizes must match in all dimensions except `concat_dim`.
axis: 0-D. The dimension along which to concatenate. Must be in the
range [0, rank(values)).
-output: An `Output` with the concatenation of values stacked along the
+output: A `Tensor` with the concatenation of values stacked along the
`concat_dim` dimension. This tensor's shape matches that of `values` except
in `concat_dim` where it has the sum of the sizes.
)doc");
@@ -4395,7 +4395,7 @@ input_mins: The minimum scalar values for each of the input tensors.
input_maxes: The maximum scalar values for each of the input tensors.
output_min: The float value that the minimum quantized output value represents.
output_max: The float value that the maximum quantized output value represents.
-output: An `Output` with the concatenation of values stacked along the
+output: A `Tensor` with the concatenation of values stacked along the
`concat_dim` dimension. This tensor's shape matches that of `values` except
in `concat_dim` where it has the sum of the sizes.
)doc");
@@ -4512,7 +4512,7 @@ operator which extracts values or slices from a given tensor.
TODO(simister): Add a link to Variable.__getitem__ documentation on slice
syntax.
-`shape` is a `TensorShape` with rank `P` and `indices` is an `Output` of rank
+`shape` is a `TensorShape` with rank `P` and `indices` is a `Tensor` of rank
`Q`.
`indices` must be integer tensor, containing indices into `shape`.
diff --git a/tensorflow/core/ops/linalg_ops.cc b/tensorflow/core/ops/linalg_ops.cc
index 90a33f7e6c..c8cae11305 100644
--- a/tensorflow/core/ops/linalg_ops.cc
+++ b/tensorflow/core/ops/linalg_ops.cc
@@ -304,7 +304,7 @@ e, v = self_adjoint_eig(a)
e = self_adjoint_eig(a, compute_v=False)
```
-input: `Output` input of shape `[N, N]`.
+input: `Tensor` input of shape `[N, N]`.
compute_v: If `True` then eigenvectors will be computed and returned in `v`.
Otherwise, only the eigenvalues will be computed.
e: Eigenvalues. Shape is `[N]`.
diff --git a/tensorflow/core/ops/logging_ops.cc b/tensorflow/core/ops/logging_ops.cc
index 5bf4e306ef..42bd12a5b3 100644
--- a/tensorflow/core/ops/logging_ops.cc
+++ b/tensorflow/core/ops/logging_ops.cc
@@ -153,7 +153,7 @@ normalization algorithms:
is at 127. They are then rescaled so that either the smallest value is 0,
or the largest one is 255.
-The `tag` argument is a scalar `Output` of type `string`. It is used to
+The `tag` argument is a scalar `Tensor` of type `string`. It is used to
build the `tag` of the summary values:
* If `max_images` is 1, the summary value tag is '*tag*/image'.
@@ -190,7 +190,7 @@ audio is built from `tensor` which must be 3-D with shape `[batch_size,
frames, channels]` or 2-D with shape `[batch_size, frames]`. The values are
assumed to be in the range of `[-1.0, 1.0]` with a sample rate of `sample_rate`.
-The `tag` argument is a scalar `Output` of type `string`. It is used to
+The `tag` argument is a scalar `Tensor` of type `string`. It is used to
build the `tag` of the summary values:
* If `max_outputs` is 1, the summary value tag is '*tag*/audio'.
@@ -220,7 +220,7 @@ audio is built from `tensor` which must be 3-D with shape `[batch_size,
frames, channels]` or 2-D with shape `[batch_size, frames]`. The values are
assumed to be in the range of `[-1.0, 1.0]` with a sample rate of `sample_rate`.
-The `tag` argument is a scalar `Output` of type `string`. It is used to
+The `tag` argument is a scalar `Tensor` of type `string`. It is used to
build the `tag` of the summary values:
* If `max_outputs` is 1, the summary value tag is '*tag*/audio'.
diff --git a/tensorflow/core/ops/math_ops.cc b/tensorflow/core/ops/math_ops.cc
index f854ad288b..9e692ed0bc 100644
--- a/tensorflow/core/ops/math_ops.cc
+++ b/tensorflow/core/ops/math_ops.cc
@@ -92,7 +92,7 @@ REGISTER_OP("BatchMatMul")
.Doc(R"doc(
Multiplies slices of two tensors in batches.
-Multiplies all slices of `Output` `x` and `y` (each slice can be
+Multiplies all slices of `Tensor` `x` and `y` (each slice can be
viewed as an element of a batch), and arranges the individual results
in a single output tensor of the same batch size. Each of the
individual slices can optionally be adjointed (to adjoint a matrix
@@ -1064,11 +1064,11 @@ select(condition, t, e) ==> [[1, 2],
```
-t:= An `Output` which may have the same shape as `condition`.
+t:= A `Tensor` which may have the same shape as `condition`.
If `condition` is rank 1, `t` may have higher rank,
but its first dimension must match the size of `condition`.
-e:= An `Output` with the same type and shape as `t`.
-output:= An `Output` with the same type and shape as `t` and `e`.
+e:= A `Tensor` with the same type and shape as `t`.
+output:= A `Tensor` with the same type and shape as `t` and `e`.
)doc");
// --------------------------------------------------------------------------
diff --git a/tensorflow/core/ops/sparse_ops.cc b/tensorflow/core/ops/sparse_ops.cc
index c115894f29..860b3475e9 100644
--- a/tensorflow/core/ops/sparse_ops.cc
+++ b/tensorflow/core/ops/sparse_ops.cc
@@ -199,7 +199,7 @@ REGISTER_OP("SerializeSparse")
return Status::OK();
})
.Doc(R"doc(
-Serialize a `SparseTensor` into a string 3-vector (1-D `Output`) object.
+Serialize a `SparseTensor` into a string 3-vector (1-D `Tensor`) object.
sparse_indices: 2-D. The `indices` of the `SparseTensor`.
sparse_values: 1-D. The `values` of the `SparseTensor`.
@@ -221,7 +221,7 @@ REGISTER_OP("SerializeManySparse")
return Status::OK();
})
.Doc(R"doc(
-Serialize an `N`-minibatch `SparseTensor` into an `[N, 3]` string `Output`.
+Serialize an `N`-minibatch `SparseTensor` into an `[N, 3]` string `Tensor`.
The `SparseTensor` must have rank `R` greater than 1, and the first dimension
is treated as the minibatch dimension. Elements of the `SparseTensor`
@@ -621,7 +621,7 @@ REGISTER_OP("SparseTensorDenseAdd")
return Status::OK();
})
.Doc(R"doc(
-Adds up a `SparseTensor` and a dense `Output`, producing a dense `Output`.
+Adds up a `SparseTensor` and a dense `Tensor`, producing a dense `Tensor`.
This Op does not require `a_indices` be sorted in standard lexicographic order.
@@ -644,7 +644,7 @@ REGISTER_OP("SparseReduceSum")
Computes the sum of elements across dimensions of a SparseTensor.
This Op takes a SparseTensor and is the sparse counterpart to
-`tf.reduce_sum()`. In particular, this Op also returns a dense `Output`
+`tf.reduce_sum()`. In particular, this Op also returns a dense `Tensor`
instead of a sparse one.
Reduces `sp_input` along the dimensions given in `reduction_axes`. Unless
diff --git a/tensorflow/core/ops/string_ops.cc b/tensorflow/core/ops/string_ops.cc
index 266a54c768..53d75e4519 100644
--- a/tensorflow/core/ops/string_ops.cc
+++ b/tensorflow/core/ops/string_ops.cc
@@ -308,9 +308,9 @@ REGISTER_OP("Substr")
return shape_inference::BroadcastBinaryOpShapeFn(c);
})
.Doc(R"doc(
-Return substrings from `Output` of strings.
+Return substrings from `Tensor` of strings.
-For each string in the input `Output`, creates a substring starting at index
+For each string in the input `Tensor`, creates a substring starting at index
`pos` with a total length of `len`.
If `len` defines a substring that would extend beyond the length of the input
diff --git a/tensorflow/core/ops/state_ops.cc b/tensorflow/core/ops/state_ops.cc
index cb1c2ec6ea..b300fbbe26 100644
--- a/tensorflow/core/ops/state_ops.cc
+++ b/tensorflow/core/ops/state_ops.cc
@@ -516,7 +516,7 @@ REGISTER_OP("ScatterNdUpdate")
Applies sparse `updates` to individual values or slices within a given
variable according to `indices`.
-`ref` is an `Output` with rank `P` and `indices` is an `Output` of rank `Q`.
+`ref` is a `Tensor` with rank `P` and `indices` is a `Tensor` of rank `Q`.
`indices` must be integer tensor, containing indices into `ref`.
It must be shape `[d_0, ..., d_{Q-2}, K]` where `0 < K <= P`.
@@ -525,7 +525,7 @@ The innermost dimension of `indices` (with length `K`) corresponds to
indices into elements (if `K = P`) or slices (if `K < P`) along the `K`th
dimension of `ref`.
-`updates` is `Output` of rank `Q-1+P-K` with shape:
+`updates` is `Tensor` of rank `Q-1+P-K` with shape:
```
[d_0, ..., d_{Q-2}, ref.shape[K], ..., ref.shape[P-1]].
@@ -573,7 +573,7 @@ REGISTER_OP("ScatterNdAdd")
Applies sparse addition between `updates` and individual values or slices
within a given variable according to `indices`.
-`ref` is an `Output` with rank `P` and `indices` is an `Output` of rank `Q`.
+`ref` is a `Tensor` with rank `P` and `indices` is a `Tensor` of rank `Q`.
`indices` must be integer tensor, containing indices into `ref`.
It must be shape `[d_0, ..., d_{Q-2}, K]` where `0 < K <= P`.
@@ -582,7 +582,7 @@ The innermost dimension of `indices` (with length `K`) corresponds to
indices into elements (if `K = P`) or slices (if `K < P`) along the `K`th
dimension of `ref`.
-`updates` is `Output` of rank `Q-1+P-K` with shape:
+`updates` is `Tensor` of rank `Q-1+P-K` with shape:
```
[d_0, ..., d_{Q-2}, ref.shape[K], ..., ref.shape[P-1]].
@@ -630,7 +630,7 @@ REGISTER_OP("ScatterNdSub")
Applies sparse subtraction between `updates` and individual values or slices
within a given variable according to `indices`.
-`ref` is an `Output` with rank `P` and `indices` is an `Output` of rank `Q`.
+`ref` is a `Tensor` with rank `P` and `indices` is a `Tensor` of rank `Q`.
`indices` must be integer tensor, containing indices into `ref`.
It must be shape `[d_0, ..., d_{Q-2}, K]` where `0 < K <= P`.
@@ -639,7 +639,7 @@ The innermost dimension of `indices` (with length `K`) corresponds to
indices into elements (if `K = P`) or slices (if `K < P`) along the `K`th
dimension of `ref`.
-`updates` is `Output` of rank `Q-1+P-K` with shape:
+`updates` is `Tensor` of rank `Q-1+P-K` with shape:
```
[d_0, ..., d_{Q-2}, ref.shape[K], ..., ref.shape[P-1]].
@@ -690,7 +690,7 @@ output_ref: Same as ref. Returned as a convenience for operations that want
// R"doc(Applies sparse subtraction between `updates` and individual
// values or slices within a given variable according to `indices`.
// `ref` is an `Output` with rank `P` and `indices` is an `Output` of rank `Q`.
// `indices` must be integer tensor, containing indices into `ref`.
// It must be shape `[d_0, ..., d_{Q-2}, K]` where `0 < K <= P`.
@@ -699,7 +699,7 @@ output_ref: Same as ref. Returned as a convenience for operations that want
// indices into elements (if `K = P`) or slices (if `K < P`) along the `K`th
// dimension of `ref`.
// `updates` is `Output` of rank `Q-1+P-K` with shape:
// ```
// [d_0, ..., d_{Q-2}, ref.shape[K], ..., ref.shape[P-1]].
@@ -746,7 +746,7 @@ output_ref: Same as ref. Returned as a convenience for operations that want
// R"doc(Applies sparse subtraction between `updates` and individual
// values or slices within a given variable according to `indices`.
// `ref` is an `Output` with rank `P` and `indices` is an `Output` of rank `Q`.
// `indices` must be integer tensor, containing indices into `ref`.
// It must be shape `[d_0, ..., d_{Q-2}, K]` where `0 < K <= P`.
@@ -755,7 +755,7 @@ output_ref: Same as ref. Returned as a convenience for operations that want
// indices into elements (if `K = P`) or slices (if `K < P`) along the `K`th
// dimension of `ref`.
// `updates` is `Output` of rank `Q-1+P-K` with shape:
// ```
// [d_0, ..., d_{Q-2}, ref.shape[K], ..., ref.shape[P-1]].
@@ -690,7 +690,7 @@ output_ref: Same as ref. Returned as a convenience for operations that want
// R"doc(Applies sparse subtraction between `updates` and individual
// values or slices within a given variable according to `indices`.
-// `ref` is an `Output` with rank `P` and `indices` is an `Output` of rank `Q`.
+// `ref` is a `Tensor` with rank `P` and `indices` is a `Tensor` of rank `Q`.
// `indices` must be integer tensor, containing indices into `ref`.
// It must be shape `[d_0, ..., d_{Q-2}, K]` where `0 < K <= P`.
@@ -699,7 +699,7 @@ output_ref: Same as ref. Returned as a convenience for operations that want
// indices into elements (if `K = P`) or slices (if `K < P`) along the `K`th
// dimension of `ref`.
-// `updates` is `Output` of rank `Q-1+P-K` with shape:
+// `updates` is `Tensor` of rank `Q-1+P-K` with shape:
// ```
// [d_0, ..., d_{Q-2}, ref.shape[K], ..., ref.shape[P-1]].
@@ -746,7 +746,7 @@ output_ref: Same as ref. Returned as a convenience for operations that want
// R"doc(Applies sparse subtraction between `updates` and individual
// values or slices within a given variable according to `indices`.
-// `ref` is an `Output` with rank `P` and `indices` is an `Output` of rank `Q`.
+// `ref` is a `Tensor` with rank `P` and `indices` is a `Tensor` of rank `Q`.
// `indices` must be integer tensor, containing indices into `ref`.
// It must be shape `[d_0, ..., d_{Q-2}, K]` where `0 < K <= P`.
@@ -755,7 +755,7 @@ output_ref: Same as ref. Returned as a convenience for operations that want
// indices into elements (if `K = P`) or slices (if `K < P`) along the `K`th
// dimension of `ref`.
-// `updates` is `Output` of rank `Q-1+P-K` with shape:
+// `updates` is `Tensor` of rank `Q-1+P-K` with shape:
// ```
// [d_0, ..., d_{Q-2}, ref.shape[K], ..., ref.shape[P-1]].